aboutsummaryrefslogtreecommitdiff
path: root/engines/sword2/maketext.cpp
diff options
context:
space:
mode:
authorMatthew Hoops2011-05-31 14:16:29 -0400
committerMatthew Hoops2011-05-31 14:16:29 -0400
commitaa49b38c5a8032586cb94fc4ca07149eecabe64a (patch)
treeea5c7617f8c482c8cf4141b728b3ccff5a7f84c7 /engines/sword2/maketext.cpp
parentd3ea9ab2a9334747eb445c1b45aa30cb17ffdf1b (diff)
parentc86a6c466fabe31fbf36363aa8d0ac8ea6001b9f (diff)
downloadscummvm-rg350-aa49b38c5a8032586cb94fc4ca07149eecabe64a.tar.gz
scummvm-rg350-aa49b38c5a8032586cb94fc4ca07149eecabe64a.tar.bz2
scummvm-rg350-aa49b38c5a8032586cb94fc4ca07149eecabe64a.zip
Merge remote branch 'upstream/master' into t7g-ios
Conflicts: engines/groovie/script.cpp
Diffstat (limited to 'engines/sword2/maketext.cpp')
-rw-r--r--engines/sword2/maketext.cpp21
1 files changed, 9 insertions, 12 deletions
diff --git a/engines/sword2/maketext.cpp b/engines/sword2/maketext.cpp
index fda30981c8..e279284d76 100644
--- a/engines/sword2/maketext.cpp
+++ b/engines/sword2/maketext.cpp
@@ -20,9 +20,6 @@
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
*/
// MAKETEXT - Constructs a single-frame text sprite: returns a handle to a
@@ -115,7 +112,7 @@ byte *FontRenderer::makeTextSprite(byte *sentence, uint16 maxWidth, uint8 pen, u
// Get details of sentence breakdown into array of LineInfo structures
// and get the number of lines involved
- uint16 noOfLines = analyseSentence(sentence, maxWidth, fontRes, (LineInfo *)line);
+ uint16 noOfLines = analyzeSentence(sentence, maxWidth, fontRes, (LineInfo *)line);
// Construct the sprite based on the info gathered - returns floating
// mem block
@@ -126,7 +123,7 @@ byte *FontRenderer::makeTextSprite(byte *sentence, uint16 maxWidth, uint8 pen, u
return textSprite;
}
-uint16 FontRenderer::analyseSentence(byte *sentence, uint16 maxWidth, uint32 fontRes, LineInfo *line) {
+uint16 FontRenderer::analyzeSentence(byte *sentence, uint16 maxWidth, uint32 fontRes, LineInfo *line) {
// joinWidth = how much extra space is needed to append a word to a
// line. NB. SPACE requires TWICE the '_charSpacing' to join a word
// to line
@@ -202,7 +199,7 @@ uint16 FontRenderer::analyseSentence(byte *sentence, uint16 maxWidth, uint32 fon
* @param sentence pointer to a null-terminated string
* @param fontRes the font resource id
* @param pen the text color, or zero to use the source colors
- * @param line array of LineInfo structures, created by analyseSentence()
+ * @param line array of LineInfo structures, created by analyzeSentence()
* @param noOfLines the number of lines, i.e. the number of elements in 'line'
* @return a handle to a floating memory block containing the text sprite
* @note The sentence must contain no leading, trailing or extra spaces.
@@ -639,7 +636,7 @@ void FontRenderer::killTextBloc(uint32 bloc_number) {
#define SAVE_LINE_NO 1
-void Sword2Engine::initialiseFontResourceFlags() {
+void Sword2Engine::initializeFontResourceFlags() {
byte *textFile = _resman->openResource(TEXT_RES);
// If language is Polish or Finnish it requires alternate fonts.
@@ -652,11 +649,11 @@ void Sword2Engine::initialiseFontResourceFlags() {
char *textLine = (char *)fetchTextLine(textFile, SAVE_LINE_NO) + 2;
if (strcmp(textLine, "tallenna") == 0)
- initialiseFontResourceFlags(FINNISH_TEXT);
+ initializeFontResourceFlags(FINNISH_TEXT);
else if (strcmp(textLine, "zapisz") == 0)
- initialiseFontResourceFlags(POLISH_TEXT);
+ initializeFontResourceFlags(POLISH_TEXT);
else
- initialiseFontResourceFlags(DEFAULT_TEXT);
+ initializeFontResourceFlags(DEFAULT_TEXT);
// Get the game name for the windows application
@@ -680,10 +677,10 @@ void Sword2Engine::initialiseFontResourceFlags() {
}
/**
* Called from initialiseFontResourceFlags(), and also from console.cpp
*/
-void Sword2Engine::initialiseFontResourceFlags(uint8 language) {
+void Sword2Engine::initializeFontResourceFlags(uint8 language) {
switch (language) {
case FINNISH_TEXT:
_speechFontId = FINNISH_SPEECH_FONT_ID;
@@ -680,10 +677,10 @@ void Sword2Engine::initialiseFontResourceFlags() {
}
/**
- * Called from initialiseFontResourceFlags(), and also from console.cpp
+ * Called from initializeFontResourceFlags(), and also from console.cpp
*/